# This file was automatically generated by update_user_agents.py using data
# from <https://techblog.willshouse.com/2012/01/03/most-common-user-agents/>.

# flake8: noqa
USER_AGENTS = [
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.121",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.86",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:65.0) Gecko/20100101 Firefox/65.0",
        {
            "os": "Windows",
            "browser": "Firefox",
            "device": "",
            "browser_version": "65.0",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36",
        {
            "os": "Mac OS X",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.121",
            "os_version": "10.14.3"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_3) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0.3 Safari/605.1.15",
        {
            "os": "Mac OS X",
            "browser": "Safari",
            "device": "",
            "browser_version": "12.0.3",
            "os_version": "10.14.3"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.121",
            "os_version": "Server 2008 R2 / 7"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        {
            "os": "Windows",
            "browser": "Firefox",
            "device": "",
            "browser_version": "66.0",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.119 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.119",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.140 Safari/537.36 Edge/17.17134",
        {
            "os": "Windows",
            "browser": "Microsoft Edge",
            "device": "",
            "browser_version": "17.17134",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.75 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.75",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:65.0) Gecko/20100101 Firefox/65.0",
        {
            "os": "Windows",
            "browser": "Firefox",
            "device": "",
            "browser_version": "65.0",
            "os_version": "Server 2008 R2 / 7"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.86",
            "os_version": "Server 2008 R2 / 7"
        }
    ],
    [
        "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:65.0) Gecko/20100101 Firefox/65.0",
        {
            "os": "Linux",
            "browser": "Firefox",
            "device": "",
            "browser_version": "65.0",
            "os_version": ""
        }
    ],
    [
        "Mozilla/5.0 (X11; Linux x86_64; rv:60.0) Gecko/20100101 Firefox/60.0",
        {
            "os": "Linux",
            "browser": "Firefox",
            "device": "",
            "browser_version": "60.0",
            "os_version": ""
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36",
        {
            "os": "Mac OS X",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.86",
            "os_version": "10.14.3"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.140 Safari/537.36 Edge/18.17763",
        {
            "os": "Windows",
            "browser": "Microsoft Edge",
            "device": "",
            "browser_version": "18.17763",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36",
        {
            "os": "Mac OS X",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.121",
            "os_version": "10.13.6"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 6.1; rv:60.0) Gecko/20100101 Firefox/60.0",
        {
            "os": "Windows",
            "browser": "Firefox",
            "device": "",
            "browser_version": "60.0",
            "os_version": "Server 2008 R2 / 7"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.109 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.109",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.119 Safari/537.36",
        {
            "os": "Mac OS X",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.119",
            "os_version": "10.14.3"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/71.0.3578.98 Safari/537.36",
        {
            "os": "Windows",
            "browser": "Chrome",
            "device": "",
            "browser_version": "71.0.3578.98",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.14; rv:65.0) Gecko/20100101 Firefox/65.0",
        {
            "os": "Mac OS X",
            "browser": "Firefox",
            "device": "",
            "browser_version": "65.0",
            "os_version": "10"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0.3 Safari/605.1.15",
        {
            "os": "Mac OS X",
            "browser": "Safari",
            "device": "",
            "browser_version": "12.0.3",
            "os_version": "10.13.6"
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36",
        {
            "os": "Mac OS X",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.86",
            "os_version": "10.14.4"
        }
    ],
    [
        "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        {
            "os": "Windows",
            "browser": "Firefox",
            "device": "",
            "browser_version": "66.0",
            "os_version": "Server 2008 R2 / 7"
        }
    ],
    [
        "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36",
        {
            "os": "Linux",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.86",
            "os_version": ""
        }
    ],
    [
        "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36",
        {
            "os": "Linux",
            "browser": "Chrome",
            "device": "",
            "browser_version": "72.0.3626.121",
            "os_version": ""
        }
    ],
    [
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36",
        {
            "os": "Mac OS X",
            "browser": "Chrome",
            "device": "",
            "browser_version": "73.0.3683.86",
            "os_version": "10.13.6"
        }
    ]
]
